@@ -1,13 +1,15 @@
 # Copyright 2022 DEViantUa <t.me/deviant_ua>
 # All rights reserved.
 from enkanetwork import EnkaNetworkAPI,Assets
-import logging,asyncio,random, os, datetime,time
+import logging,asyncio,random,os,datetime
 from threading import Thread
 from .src.utils.CreatBannerTwo import generationTwo, creatUserInfo
 from .src.utils.CreatBannerOne import generationOne, signature, openUserImg 
+from .src.utils.userProfile import creatUserProfile
 from .src.utils.translation import translationLang,supportLang
 from .enc_error import ENCardError
-    
+
+
 logging.getLogger('enkanetwork.assets').setLevel(logging.CRITICAL)
 
 def upload():
@@ -33,6 +35,7 @@ def uidCreat(uids):
 def saveBanner(uid,res,name):
     data = datetime.datetime.now().strftime("%d_%m_%Y %H_%M")
     path = os.getcwd()
+
     try:
         os.mkdir(f'{path}/EnkaImg')
     except:
@@ -41,8 +44,8 @@ def saveBanner(uid,res,name):
         os.mkdir(f'{path}/EnkaImg/{uid}')
     except:
         pass
-    res.save(f"{path}/EnkaImg/{uid}/{name}_{data}.png")
 
+    res.save(f"{path}/EnkaImg/{uid}/{name}_{data}.png")
 def generation(charter,assets,img,adapt,uid,RESULT, save,signatureRes,translateLang,splash,teample = 1):
     if teample == 1:
         result = generationOne(charter,assets,img,adapt,signatureRes,translateLang["lvl"],splash)
@@ -66,6 +69,7 @@ class EnkaGenshinGeneration:
             randomImg = False, hide = False, dowload = False, namecard = False, splash = False):
         if not lang in supportLang:
             raise ENCardError(6,"Dislike language List of available languages: en, ru, vi, th, pt, kr, jp, zh, id, fr, es, de, chs, cht.\nRead more in the documentation: https://github.com/DEViantUA/EnkaNetworkCard")
+        
         self.assets = Assets(lang=lang)
         self.lang = lang
         self.splash = splash
@@ -106,12 +110,26 @@ class EnkaGenshinGeneration:
             if img:
                 self.img = openUserImg(img)
     
-    def start(self,uids, template = 1):
 
+    def profile(self,uid, image = True):
+        if type(uid) == int:
+            if int(uid) > 0:
+                profile = asyncio.run(info(uid,self.lang))
+            else:
+                raise ENCardError(7, "The UID argument must be a number and greater than 0")
+        else:
+            raise ENCardError(7, "The UID argument must be a number and greater than 0")
+        itog = creatUserProfile(image,profile.player,self.translateLang,self.hide,uid,self.assets)
+
+        return itog
+        
+    def start(self,uids, template = 1, name = None):
         if self.FIX_ASYNCIO_WIN:
             asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
         startPotoki = {}
         ResultEnka = {}
+        if name:
+            self.name = name
         if template < 1 or template > 2:
             raise ENCardError(1, "The teamle parameter supports values ​​from 1 to 2")
         uids = uidCreat(uids)
@@ -124,14 +142,14 @@ class EnkaGenshinGeneration:
             else:
                 signatureRes = creatUserInfo(self.hide,uid,r.player,self.translateLang)
             for key in r.characters:
+                if self.name:
+                    if not key.name.replace(' ', '').lower() in self.name:
+                        continue
                 self.characterImg(key.name.lower())
                 if self.namecard and template == 2:
                     signatureRes = creatUserInfo(self.hide,uid,r.player,self.translateLang,key.image.icon.filename.replace("CostumeFloral","").split("AvatarIcon_")[1],self.namecard)
-                if self.name:
-                    if not key.name.lower() in self.name:
-                        continue
                 self.startNameGeneration(key,uid,startPotoki,ResultEnka,signatureRes,template)
-                time.sleep(0.3)
+
         return self.dowloadImg(startPotoki,ResultEnka)
     
     def characterImg(self,name):
@@ -147,8 +165,7 @@ class EnkaGenshinGeneration:
                 startPotoki[f"{uid}_{key.name.lower()}"] = Thread(target=generation,args=(key,self.assets,openUserImg(random.choice(self.img)),self.adapt,uid,ResultEnka,self.dowload,signatureRes,self.translateLang,self.splash, teample))
             else:
                 startPotoki[f"{uid}_{key.name.lower()}"] = Thread(target=generation,args=(key,self.assets,self.img,self.adapt,uid,ResultEnka,self.dowload,signatureRes,self.translateLang,self.splash, teample))
-            startPotoki[f"{uid}_{key.name.lower()}"].start()    
-
+            startPotoki[f"{uid}_{key.name.lower()}"].start()
     def dowloadImg(self,startPotoki,ResultEnka):
         if self.dowload:
             for key in startPotoki:
